@@ -63,13 +63,12 @@ class CLI(object):
                 except Exception as e:
                     print >>sys.stderr, "Failed plugin {0}:{1}: {2}!".format(plugin, plugin.alias, e)
 
-        # Generate mail template
+        # TODO: Generate mail template
 
         # Print results sorted by plugin appearance in config file (i.e. init order):
         for plugin in self.plugins:
             try:
                 print results[plugin]
-                pass
             except KeyError as e:
                 # A missing result for plugins means an exception happened
                 # above, which already printed an error message, thus:
